@@ -1,4 +1,4 @@
-## Copyright 2010-2013 Sebastian Gibb
+## Copyright 2010-2014 Sebastian Gibb
 ## <mail@sebastiangibb.de>
 ##
 ## This file is part of readBrukerFlexData for R and related languages.
@@ -152,7 +152,7 @@
   metaData <- list()
 
   ## endianness
-  isBigEndian <- as.integer(.grepAcquValue("##\\$BYTORDA=", acquLines)) == 1
+  isBigEndian <- as.integer(.grepAcquValue("##\\$BYTORDA=", acquLines)) == 1L
   metaData$byteOrder <- ifelse(isBigEndian, "big", "little")
 
   ## obligate
@@ -174,9 +174,9 @@
 
   ## was HPC involved?  metaData$hpcUse seems to be always true
   isHPCused <- isTRUE(metaData$hpcUse &&
-                      metaData$hpcLimits["maxMass"] > 0 &&
-                      metaData$hpcLimits["minMass"] > 0 &&
-                      metaData$hpcOrder > 0)
+                      metaData$hpcLimits["maxMass"] > 0L &&
+                      metaData$hpcLimits["minMass"] > 0L &&
+                      metaData$hpcOrder > 0L)
 
   if (isHPCused) {
     hpcStr <- .grepAcquValue("##\\$HPCStr=", acquLines)
@@ -186,6 +186,11 @@
     metaData$hpcCalibrationConstant2 <- hpcConstants$calibrationConstant2
   }
 
+  # https://github.com/sgibb/MALDIquantForeign/issues/19
+  metaData$v1tofCalibration <-
+    grepl("V1.0CTOF2CalibrationConstants",
+          .grepAcquValue("##\\$NTBCal=", acquLines))
+
   ## obligate LIFT
   metaData$lift <- c(.grepAcquDoubleValue("##\\$Lift1=", acquLines),
                      .grepAcquDoubleValue("##\\$Lift2=", acquLines))
@@ -267,13 +272,30 @@
 
   metaData$instrument <- .grepAcquValue("##\\$INSTRUM=", acquLines)
   metaData$instrumentId <- .grepAcquValue("##\\$InstrID=", acquLines)
-  metaData$instrumentType <- .grepAcquValue("##\\$InstTyp=", acquLines)
+
+  instrumentType <- .grepAcquValue("##\\$InstTyp=", acquLines)
+  if (length(instrumentType)) {
+    metaData$instrumentType <- switch(instrumentType,
+        "0" = { "autoflex" },
+        "1" = { "ultraflex" },
+        "2" = { "ultraflexTOF/TOF" },
+        "3" = { "reflex" },
+        "4" = { "biflex" },
+        "5" = { "omniflex" },
+        "6" = { "genoflex" },
+        "7" = { "massarray" },
+        "8" = { "autoflexTOF/TOF" },
+        "9" = { "microflex" },
+       "10" = { "MT10" },
+        { instrumentType }
+    )
+  }
 
   metaData$massError <- .grepAcquDoubleValue("##\\$Masserr=", acquLines)
 
   metaData$laserShots <- as.double(.grepAcquValue("##\\$NoSHOTS=", acquLines))
 
-  if (metaData$laserShots == 0) {
+  if (metaData$laserShots == 0L) {
     warning("File ", sQuote(fidFile), " seems to be empty because ",
             "no laser shots applied to this sample.")
   }
@@ -284,12 +306,12 @@
   if (length(metaData$patch) &&
       grepl(pattern="(R[0-9]+)?X[0-9]+Y[0-9]+", x=metaData$patch,
             ignore.case=TRUE)) {
-    rx <- gregexpr(pattern="[XY][0-9]+", text=metaData$patch)[[1]]
-    pos <- substring(metaData$patch, rx+1, rx+attr(rx, "match.length")-1)
+    rx <- gregexpr(pattern="[XY][0-9]+", text=metaData$patch)[[1L]]
+    pos <- substring(metaData$patch, rx+1L, rx+attr(rx, "match.length")-1L)
 
-    if (length(pos) == 2) {
+    if (length(pos) == 2L) {
       pos <- as.double(pos)
-      metaData$imaging <- list(pos=c(x=pos[1], y=pos[2]))
+      metaData$imaging <- list(pos=c(x=pos[1L], y=pos[2L]))
     }
   }
 
@@ -319,6 +341,6 @@
   metaData$fullName <- paste(metaData$sampleName, metaData$patch, sep=".")
   metaData$name <- metaData$fullName
 
-  return(metaData)
+  metaData
 }
 
